function res = isBounded(pZ)
% isBounded - determines if a polynomial zonotope is bounded
%
% Syntax:
%    res = isBounded(pZ)
%
% Inputs:
%    pZ - polyZonotope object
%
% Outputs:
%    res - true/false
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Authors:       Mark Wetzlinger
% Written:       24-July-2023
% Last update:   ---
% Last revision: ---

% ------------------------------ BEGIN CODE -------------------------------

% always bounded
res = true;

% ------------------------------ END OF CODE ------------------------------
